import glob
import numpy as np
import cv2
import matplotlib.pyplot as plt
import seaborn as sns
import pandas as pd
import os
import re
from scipy import signal
from sklearn.linear_model import LinearRegression
plt.rcParams['pdf.fonttype'] = 42


if __name__ == "__main__":
    cmap = sns.color_palette()

    dirs = glob.glob("./_HS*")
    strains = sorted([k[3:] for k in dirs])  # strainを重複なく抜き出す

    for cmp in strains:
        data_RFP = pd.DataFrame({})
        data_CFP = pd.DataFrame({})
        data_FRET = pd.DataFrame({})
        data_length = pd.DataFrame({})

        temp_RFP = pd.read_csv("./_" + cmp + "\_results_tot_RFP.csv")
        temp_CFP = pd.read_csv("./_" + cmp + "\_results_tot_CFP.csv")
        temp_FRET = pd.read_csv("./_" + cmp + "\_results_tot_FRET.csv")
        temp_length = pd.read_csv("./_" + cmp + "\_results_tot_length.csv")

        data_RFP = pd.concat([data_RFP, temp_RFP], ignore_index=True)
        data_CFP = pd.concat([data_CFP, temp_CFP], ignore_index=True)
        data_FRET = pd.concat([data_FRET, temp_FRET], ignore_index=True)
        data_length = pd.concat([data_length, temp_length], ignore_index=True)

        data_plt = pd.DataFrame({})
        data_plt["ratio"] = data_FRET["Mean"] / data_CFP["Mean"]
        data_plt["cdc13"] = data_RFP["Mean"]
        data_plt["length"] = data_length["Length"]
        data_plt["strain"] = data_FRET["strain"]

        data_plt.drop(data_plt.loc[data_plt["length"] > 50].index, inplace=True)

        fig, ax1 = plt.subplots(figsize=(8, 6))
        ax2 = ax1.twinx()
        sns.scatterplot(x="length", y="ratio", data=data_plt, alpha=0.3, ax=ax1, color="blue")
        sns.scatterplot(x="length", y="cdc13", data=data_plt, alpha=0.3, ax=ax2, color="red")
        plt.xlim(6, 20)
        ax1.set_ylim(1.4, 2.2)
        ax2.set_ylim(-200, 1100)
        plt.savefig("./__length-vs-FRET_" + cmp + ".png")
        plt.savefig("./__length-vs-FRET_" + cmp + ".pdf")
        plt.close(fig)
